# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/agent_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/agent_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/loadtesting/agent/v1/agent_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\x96\x02\n\x17\x43laimAgentStatusRequest\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\x12Q\n\x06status\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest.Status\"\x8c\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eREADY_FOR_TEST\x10\x01\x12\x12\n\x0ePREPARING_TEST\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0f\n\x0bTANK_FAILED\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x17\n\x13UPLOADING_ARTIFACTS\x10\x06\"(\n\x18\x43laimAgentStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x32\xe0\x01\n\x0c\x41gentService\x12\xcf\x01\n\x0b\x43laimStatus\x12:.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest\x1a;.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusResponse\"G\x82\xd3\xe4\x93\x02\x41\"</loadtesting/agent/v1/agents/{agent_instance_id}/claimStatus:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CLAIMAGENTSTATUSREQUEST_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY_FOR_TEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING_TEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TANK_FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPLOADING_ARTIFACTS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=261,
  serialized_end=401,
)
_sym_db.RegisterEnumDescriptor(_CLAIMAGENTSTATUSREQUEST_STATUS)


_CLAIMAGENTSTATUSREQUEST = _descriptor.Descriptor(
  name='ClaimAgentStatusRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest.agent_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLAIMAGENTSTATUSREQUEST_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=401,
)


_CLAIMAGENTSTATUSRESPONSE = _descriptor.Descriptor(
  name='ClaimAgentStatusResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusResponse.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=443,
)

_CLAIMAGENTSTATUSREQUEST.fields_by_name['status'].enum_type = _CLAIMAGENTSTATUSREQUEST_STATUS
_CLAIMAGENTSTATUSREQUEST_STATUS.containing_type = _CLAIMAGENTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ClaimAgentStatusRequest'] = _CLAIMAGENTSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ClaimAgentStatusResponse'] = _CLAIMAGENTSTATUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClaimAgentStatusRequest = _reflection.GeneratedProtocolMessageType('ClaimAgentStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMAGENTSTATUSREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest)
  })
_sym_db.RegisterMessage(ClaimAgentStatusRequest)

ClaimAgentStatusResponse = _reflection.GeneratedProtocolMessageType('ClaimAgentStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLAIMAGENTSTATUSRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusResponse)
  })
_sym_db.RegisterMessage(ClaimAgentStatusResponse)


DESCRIPTOR._options = None

_AGENTSERVICE = _descriptor.ServiceDescriptor(
  name='AgentService',
  full_name='yandex.cloud.loadtesting.agent.v1.AgentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=446,
  serialized_end=670,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClaimStatus',
    full_name='yandex.cloud.loadtesting.agent.v1.AgentService.ClaimStatus',
    index=0,
    containing_service=None,
    input_type=_CLAIMAGENTSTATUSREQUEST,
    output_type=_CLAIMAGENTSTATUSRESPONSE,
    serialized_options=b'\202\323\344\223\002A\"</loadtesting/agent/v1/agents/{agent_instance_id}/claimStatus:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENTSERVICE)

DESCRIPTOR.services_by_name['AgentService'] = _AGENTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/v1/subcluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.dataproc.v1 import common_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2
from yandex.cloud.dataproc.v1 import subcluster_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dataproc/v1/subcluster_service.proto',
  package='yandex.cloud.dataproc.v1',
  syntax='proto3',
  serialized_options=b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/dataproc/v1/subcluster_service.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a%yandex/cloud/dataproc/v1/common.proto\x1a)yandex/cloud/dataproc/v1/subcluster.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"]\n\x14GetSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rsubcluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x94\x01\n\x16ListSubclustersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x17ListSubclustersResponse\x12\x39\n\x0bsubclusters\x18\x01 \x03(\x0b\x32$.yandex.cloud.dataproc.v1.Subcluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xea\x02\n\x17\x43reateSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x32\n\x04role\x18\x03 \x01(\x0e\x32\x1e.yandex.cloud.dataproc.v1.RoleB\x04\xe8\xc7\x31\x01\x12<\n\tresources\x18\x04 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.ResourcesB\x04\xe8\xc7\x31\x01\x12\x1f\n\tsubnet_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x0bhosts_count\x18\x06 \x01(\x03\x42\x0b\xe8\xc7\x31\x01\xfa\xc7\x31\x03>=1\x12G\n\x12\x61utoscaling_config\x18\x07 \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\"Y\n\x18\x43reateSubclusterMetadata\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\rsubcluster_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x90\x03\n\x17UpdateSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rsubcluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x36\n\tresources\x18\x04 \x01(\x0b\x32#.yandex.cloud.dataproc.v1.Resources\x12/\n\x04name\x18\x05 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12 \n\x0bhosts_count\x18\x06 \x01(\x03\x42\x0b\xe8\xc7\x31\x01\xfa\xc7\x31\x03>=1\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x07 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12G\n\x12\x61utoscaling_config\x18\x08 \x01(\x0b\x32+.yandex.cloud.dataproc.v1.AutoscalingConfig\"Y\n\x18UpdateSubclusterMetadata\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\rsubcluster_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x8b\x01\n\x17\x44\x65leteSubclusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rsubcluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x14\x64\x65\x63ommission_timeout\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\"Y\n\x18\x44\x65leteSubclusterMetadata\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\rsubcluster_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=502\xd9\x07\n\x11SubclusterService\x12\xa3\x01\n\x03Get\x12..yandex.cloud.dataproc.v1.GetSubclusterRequest\x1a$.yandex.cloud.dataproc.v1.Subcluster\"F\x82\xd3\xe4\x93\x02@\x12>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}\x12\xa3\x01\n\x04List\x12\x30.yandex.cloud.dataproc.v1.ListSubclustersRequest\x1a\x31.yandex.cloud.dataproc.v1.ListSubclustersResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dataproc/v1/clusters/{cluster_id}/subclusters\x12\xc3\x01\n\x06\x43reate\x12\x31.yandex.cloud.dataproc.v1.CreateSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02\x33\"./dataproc/v1/clusters/{cluster_id}/subclusters:\x01*\xb2\xd2*&\n\x18\x43reateSubclusterMetadata\x12\nSubcluster\x12\xd3\x01\n\x06Update\x12\x31.yandex.cloud.dataproc.v1.UpdateSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02\x43\x32>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}:\x01*\xb2\xd2*&\n\x18UpdateSubclusterMetadata\x12\nSubcluster\x12\xdb\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.dataproc.v1.DeleteSubclusterRequest\x1a!.yandex.cloud.operation.Operation\"{\x82\xd3\xe4\x93\x02@*>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}\xb2\xd2*1\n\x18\x44\x65leteSubclusterMetadata\x12\x15google.protobuf.EmptyBe\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2.DESCRIPTOR,yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,])




_GETSUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.GetSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.GetSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.GetSubclusterRequest.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=423,
)


_LISTSUBCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListSubclustersRequest',
  full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.dataproc.v1.ListSubclustersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=574,
)


_LISTSUBCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListSubclustersResponse',
  full_name='yandex.cloud.dataproc.v1.ListSubclustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subclusters', full_name='yandex.cloud.dataproc.v1.ListSubclustersResponse.subclusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.dataproc.v1.ListSubclustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=685,
)


_CREATESUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.resources', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.subnet_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.hosts_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoscaling_config', full_name='yandex.cloud.dataproc.v1.CreateSubclusterRequest.autoscaling_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=1050,
)


_CREATESUBCLUSTERMETADATA = _descriptor.Descriptor(
  name='CreateSubclusterMetadata',
  full_name='yandex.cloud.dataproc.v1.CreateSubclusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.CreateSubclusterMetadata.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1141,
)


_UPDATESUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.resources', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosts_count', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.hosts_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\003>=1', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decommission_timeout', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.decommission_timeout', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoscaling_config', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterRequest.autoscaling_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1544,
)


_UPDATESUBCLUSTERMETADATA = _descriptor.Descriptor(
  name='UpdateSubclusterMetadata',
  full_name='yandex.cloud.dataproc.v1.UpdateSubclusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.UpdateSubclusterMetadata.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1546,
  serialized_end=1635,
)


_DELETESUBCLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteSubclusterRequest',
  full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decommission_timeout', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterRequest.decommission_timeout', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1638,
  serialized_end=1777,
)


_DELETESUBCLUSTERMETADATA = _descriptor.Descriptor(
  name='DeleteSubclusterMetadata',
  full_name='yandex.cloud.dataproc.v1.DeleteSubclusterMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterMetadata.cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subcluster_id', full_name='yandex.cloud.dataproc.v1.DeleteSubclusterMetadata.subcluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1779,
  serialized_end=1868,
)

_LISTSUBCLUSTERSRESPONSE.fields_by_name['subclusters'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._SUBCLUSTER
_CREATESUBCLUSTERREQUEST.fields_by_name['role'].enum_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._ROLE
_CREATESUBCLUSTERREQUEST.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2._RESOURCES
_CREATESUBCLUSTERREQUEST.fields_by_name['autoscaling_config'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._AUTOSCALINGCONFIG
_UPDATESUBCLUSTERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESUBCLUSTERREQUEST.fields_by_name['resources'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_common__pb2._RESOURCES
_UPDATESUBCLUSTERREQUEST.fields_by_name['autoscaling_config'].message_type = yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._AUTOSCALINGCONFIG
DESCRIPTOR.message_types_by_name['GetSubclusterRequest'] = _GETSUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListSubclustersRequest'] = _LISTSUBCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListSubclustersResponse'] = _LISTSUBCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['CreateSubclusterRequest'] = _CREATESUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateSubclusterMetadata'] = _CREATESUBCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['UpdateSubclusterRequest'] = _UPDATESUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateSubclusterMetadata'] = _UPDATESUBCLUSTERMETADATA
DESCRIPTOR.message_types_by_name['DeleteSubclusterRequest'] = _DELETESUBCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteSubclusterMetadata'] = _DELETESUBCLUSTERMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSubclusterRequest = _reflection.GeneratedProtocolMessageType('GetSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.GetSubclusterRequest)
  })
_sym_db.RegisterMessage(GetSubclusterRequest)

ListSubclustersRequest = _reflection.GeneratedProtocolMessageType('ListSubclustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBCLUSTERSREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.ListSubclustersRequest)
  })
_sym_db.RegisterMessage(ListSubclustersRequest)

ListSubclustersResponse = _reflection.GeneratedProtocolMessageType('ListSubclustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSUBCLUSTERSRESPONSE,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.ListSubclustersResponse)
  })
_sym_db.RegisterMessage(ListSubclustersResponse)

CreateSubclusterRequest = _reflection.GeneratedProtocolMessageType('CreateSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.CreateSubclusterRequest)
  })
_sym_db.RegisterMessage(CreateSubclusterRequest)

CreateSubclusterMetadata = _reflection.GeneratedProtocolMessageType('CreateSubclusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.CreateSubclusterMetadata)
  })
_sym_db.RegisterMessage(CreateSubclusterMetadata)

UpdateSubclusterRequest = _reflection.GeneratedProtocolMessageType('UpdateSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.UpdateSubclusterRequest)
  })
_sym_db.RegisterMessage(UpdateSubclusterRequest)

UpdateSubclusterMetadata = _reflection.GeneratedProtocolMessageType('UpdateSubclusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESUBCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.UpdateSubclusterMetadata)
  })
_sym_db.RegisterMessage(UpdateSubclusterMetadata)

DeleteSubclusterRequest = _reflection.GeneratedProtocolMessageType('DeleteSubclusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESUBCLUSTERREQUEST,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.DeleteSubclusterRequest)
  })
_sym_db.RegisterMessage(DeleteSubclusterRequest)

DeleteSubclusterMetadata = _reflection.GeneratedProtocolMessageType('DeleteSubclusterMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETESUBCLUSTERMETADATA,
  '__module__' : 'yandex.cloud.dataproc.v1.subcluster_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dataproc.v1.DeleteSubclusterMetadata)
  })
_sym_db.RegisterMessage(DeleteSubclusterMetadata)


DESCRIPTOR._options = None
_GETSUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_GETSUBCLUSTERREQUEST.fields_by_name['subcluster_id']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['cluster_id']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['page_size']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['page_token']._options = None
_LISTSUBCLUSTERSREQUEST.fields_by_name['filter']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['name']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['role']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['resources']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['subnet_id']._options = None
_CREATESUBCLUSTERREQUEST.fields_by_name['hosts_count']._options = None
_CREATESUBCLUSTERMETADATA.fields_by_name['cluster_id']._options = None
_CREATESUBCLUSTERMETADATA.fields_by_name['subcluster_id']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['subcluster_id']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['name']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['hosts_count']._options = None
_UPDATESUBCLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
_UPDATESUBCLUSTERMETADATA.fields_by_name['cluster_id']._options = None
_UPDATESUBCLUSTERMETADATA.fields_by_name['subcluster_id']._options = None
_DELETESUBCLUSTERREQUEST.fields_by_name['cluster_id']._options = None
_DELETESUBCLUSTERREQUEST.fields_by_name['subcluster_id']._options = None
_DELETESUBCLUSTERREQUEST.fields_by_name['decommission_timeout']._options = None
_DELETESUBCLUSTERMETADATA.fields_by_name['cluster_id']._options = None
_DELETESUBCLUSTERMETADATA.fields_by_name['subcluster_id']._options = None

_SUBCLUSTERSERVICE = _descriptor.ServiceDescriptor(
  name='SubclusterService',
  full_name='yandex.cloud.dataproc.v1.SubclusterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1871,
  serialized_end=2856,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_dataproc_dot_v1_dot_subcluster__pb2._SUBCLUSTER,
    serialized_options=b'\202\323\344\223\002@\022>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSUBCLUSTERSREQUEST,
    output_type=_LISTSUBCLUSTERSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./dataproc/v1/clusters/{cluster_id}/subclusters',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATESUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./dataproc/v1/clusters/{cluster_id}/subclusters:\001*\262\322*&\n\030CreateSubclusterMetadata\022\nSubcluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATESUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002C2>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}:\001*\262\322*&\n\030UpdateSubclusterMetadata\022\nSubcluster',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.dataproc.v1.SubclusterService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETESUBCLUSTERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002@*>/dataproc/v1/clusters/{cluster_id}/subclusters/{subcluster_id}\262\322*1\n\030DeleteSubclusterMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUBCLUSTERSERVICE)

DESCRIPTOR.services_by_name['SubclusterService'] = _SUBCLUSTERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/gpu_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/gpu_cluster.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/compute/v1/gpu_cluster.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x03\n\nGpuCluster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12?\n\x06labels\x18\x06 \x03(\x0b\x32/.yandex.cloud.compute.v1.GpuCluster.LabelsEntry\x12:\n\x06status\x18\x07 \x01(\x0e\x32*.yandex.cloud.compute.v1.GpuCluster.Status\x12\x0f\n\x07zone_id\x18\x08 \x01(\t\x12G\n\x11interconnect_type\x18\t \x01(\x0e\x32,.yandex.cloud.compute.v1.GpuInterconnectType\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04*L\n\x13GpuInterconnectType\x12%\n!GPU_INTERCONNECT_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nINFINIBAND\x10\x01\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_GPUINTERCONNECTTYPE = _descriptor.EnumDescriptor(
  name='GpuInterconnectType',
  full_name='yandex.cloud.compute.v1.GpuInterconnectType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GPU_INTERCONNECT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFINIBAND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=578,
  serialized_end=654,
)
_sym_db.RegisterEnumDescriptor(_GPUINTERCONNECTTYPE)

GpuInterconnectType = enum_type_wrapper.EnumTypeWrapper(_GPUINTERCONNECTTYPE)
GPU_INTERCONNECT_TYPE_UNSPECIFIED = 0
INFINIBAND = 1


_GPUCLUSTER_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.compute.v1.GpuCluster.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=494,
  serialized_end=576,
)
_sym_db.RegisterEnumDescriptor(_GPUCLUSTER_STATUS)


_GPUCLUSTER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.GpuCluster.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.GpuCluster.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.GpuCluster.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=492,
)

_GPUCLUSTER = _descriptor.Descriptor(
  name='GpuCluster',
  full_name='yandex.cloud.compute.v1.GpuCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.GpuCluster.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.GpuCluster.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.compute.v1.GpuCluster.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.GpuCluster.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.GpuCluster.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.GpuCluster.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.compute.v1.GpuCluster.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.GpuCluster.zone_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interconnect_type', full_name='yandex.cloud.compute.v1.GpuCluster.interconnect_type', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GPUCLUSTER_LABELSENTRY, ],
  enum_types=[
    _GPUCLUSTER_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=576,
)

_GPUCLUSTER_LABELSENTRY.containing_type = _GPUCLUSTER
_GPUCLUSTER.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GPUCLUSTER.fields_by_name['labels'].message_type = _GPUCLUSTER_LABELSENTRY
_GPUCLUSTER.fields_by_name['status'].enum_type = _GPUCLUSTER_STATUS
_GPUCLUSTER.fields_by_name['interconnect_type'].enum_type = _GPUINTERCONNECTTYPE
_GPUCLUSTER_STATUS.containing_type = _GPUCLUSTER
DESCRIPTOR.message_types_by_name['GpuCluster'] = _GPUCLUSTER
DESCRIPTOR.enum_types_by_name['GpuInterconnectType'] = _GPUINTERCONNECTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GpuCluster = _reflection.GeneratedProtocolMessageType('GpuCluster', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GPUCLUSTER_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GpuCluster.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GPUCLUSTER,
  '__module__' : 'yandex.cloud.compute.v1.gpu_cluster_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GpuCluster)
  })
_sym_db.RegisterMessage(GpuCluster)
_sym_db.RegisterMessage(GpuCluster.LabelsEntry)


DESCRIPTOR._options = None
_GPUCLUSTER_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1 import endpoint_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/transfer.proto',
  package='yandex.cloud.datatransfer.v1',
  syntax='proto3',
  serialized_options=b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+yandex/cloud/datatransfer/v1/transfer.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a+yandex/cloud/datatransfer/v1/endpoint.proto\"\xb8\x03\n\x08Transfer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.datatransfer.v1.Transfer.LabelsEntry\x12\x36\n\x06source\x18\x07 \x01(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12\x36\n\x06target\x18\x08 \x01(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12<\n\x06status\x18\n \x01(\x0e\x32,.yandex.cloud.datatransfer.v1.TransferStatus\x12\x38\n\x04type\x18\x0c \x01(\x0e\x32*.yandex.cloud.datatransfer.v1.TransferType\x12\x0f\n\x07warning\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*p\n\x0cTransferType\x12\x1d\n\x19TRANSFER_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16SNAPSHOT_AND_INCREMENT\x10\x01\x12\x11\n\rSNAPSHOT_ONLY\x10\x02\x12\x12\n\x0eINCREMENT_ONLY\x10\x03*\x9b\x01\n\x0eTransferStatus\x12\x1f\n\x1bTRANSFER_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\t\n\x05\x45RROR\x10\x06\x12\x10\n\x0cSNAPSHOTTING\x10\x07\x12\x08\n\x04\x44ONE\x10\x08\x42q\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2.DESCRIPTOR,])

_TRANSFERTYPE = _descriptor.EnumDescriptor(
  name='TransferType',
  full_name='yandex.cloud.datatransfer.v1.TransferType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSFER_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOT_AND_INCREMENT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOT_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INCREMENT_ONLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=565,
  serialized_end=677,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERTYPE)

TransferType = enum_type_wrapper.EnumTypeWrapper(_TRANSFERTYPE)
_TRANSFERSTATUS = _descriptor.EnumDescriptor(
  name='TransferStatus',
  full_name='yandex.cloud.datatransfer.v1.TransferStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRANSFER_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPSHOTTING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=680,
  serialized_end=835,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERSTATUS)

TransferStatus = enum_type_wrapper.EnumTypeWrapper(_TRANSFERSTATUS)
TRANSFER_TYPE_UNSPECIFIED = 0
SNAPSHOT_AND_INCREMENT = 1
SNAPSHOT_ONLY = 2
INCREMENT_ONLY = 3
TRANSFER_STATUS_UNSPECIFIED = 0
CREATING = 1
CREATED = 2
RUNNING = 3
STOPPING = 4
STOPPED = 5
ERROR = 6
SNAPSHOTTING = 7
DONE = 8



_TRANSFER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.datatransfer.v1.Transfer.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.datatransfer.v1.Transfer.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.datatransfer.v1.Transfer.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=563,
)

_TRANSFER = _descriptor.Descriptor(
  name='Transfer',
  full_name='yandex.cloud.datatransfer.v1.Transfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.datatransfer.v1.Transfer.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.datatransfer.v1.Transfer.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.datatransfer.v1.Transfer.name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.datatransfer.v1.Transfer.description', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.datatransfer.v1.Transfer.labels', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.datatransfer.v1.Transfer.source', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.datatransfer.v1.Transfer.target', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.datatransfer.v1.Transfer.status', index=7,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.datatransfer.v1.Transfer.type', index=8,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warning', full_name='yandex.cloud.datatransfer.v1.Transfer.warning', index=9,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSFER_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=563,
)

_TRANSFER_LABELSENTRY.containing_type = _TRANSFER
_TRANSFER.fields_by_name['labels'].message_type = _TRANSFER_LABELSENTRY
_TRANSFER.fields_by_name['source'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2._ENDPOINT
_TRANSFER.fields_by_name['target'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2._ENDPOINT
_TRANSFER.fields_by_name['status'].enum_type = _TRANSFERSTATUS
_TRANSFER.fields_by_name['type'].enum_type = _TRANSFERTYPE
DESCRIPTOR.message_types_by_name['Transfer'] = _TRANSFER
DESCRIPTOR.enum_types_by_name['TransferType'] = _TRANSFERTYPE
DESCRIPTOR.enum_types_by_name['TransferStatus'] = _TRANSFERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transfer = _reflection.GeneratedProtocolMessageType('Transfer', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSFER_LABELSENTRY,
    '__module__' : 'yandex.cloud.datatransfer.v1.transfer_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.Transfer.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSFER,
  '__module__' : 'yandex.cloud.datatransfer.v1.transfer_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.Transfer)
  })
_sym_db.RegisterMessage(Transfer)
_sym_db.RegisterMessage(Transfer.LabelsEntry)


DESCRIPTOR._options = None
_TRANSFER_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/mysql.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/datatransfer/v1/endpoint/mysql.proto',
  package='yandex.cloud.datatransfer.v1.endpoint',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/datatransfer/v1/endpoint/mysql.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\x82\x01\n\x0eOnPremiseMysql\x12\r\n\x05hosts\x18\x05 \x03(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSMode\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\"\x86\x01\n\x0fMysqlConnection\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysqlH\x00\x42\x0c\n\nconnection\"\xcd\x02\n\x1bMysqlObjectTransferSettings\x12H\n\x04view\x18\x01 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07routine\x18\x02 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12K\n\x07trigger\x18\x03 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\x12J\n\x06tables\x18\x04 \x01(\x0e\x32:.yandex.cloud.datatransfer.v1.endpoint.ObjectTransferStage\"\xa1\x03\n\x0bMysqlSource\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MysqlConnection\x12\x17\n\x0fsecurity_groups\x18\x0e \x03(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x18\n\x10service_database\x18\x0f \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x1c\n\x14include_tables_regex\x18\x0c \x03(\t\x12\x1c\n\x14\x65xclude_tables_regex\x18\r \x03(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x64\n\x18object_transfer_settings\x18\x0b \x01(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings\"\xff\x02\n\x0bMysqlTarget\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MysqlConnection\x12\x17\n\x0fsecurity_groups\x18\x10 \x03(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x10\n\x08sql_mode\x18\x05 \x01(\t\x12\x1e\n\x16skip_constraint_checks\x18\x06 \x01(\x08\x12\x10\n\x08timezone\x18\x07 \x01(\t\x12L\n\x0e\x63leanup_policy\x18\x08 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicy\x12\x18\n\x10service_database\x18\x0f \x01(\tB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2.DESCRIPTOR,])




_ONPREMISEMYSQL = _descriptor.Descriptor(
  name='OnPremiseMysql',
  full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysql',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hosts', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysql.hosts', index=0,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysql.port', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysql.tls_mode', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysql.subnet_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=275,
)


_MYSQLCONNECTION = _descriptor.Descriptor(
  name='MysqlConnection',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mdb_cluster_id', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlConnection.mdb_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_premise', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlConnection.on_premise', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlConnection.connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=278,
  serialized_end=412,
)


_MYSQLOBJECTTRANSFERSETTINGS = _descriptor.Descriptor(
  name='MysqlObjectTransferSettings',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings.view', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routine', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings.routine', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings.trigger', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tables', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings.tables', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=748,
)


_MYSQLSOURCE = _descriptor.Descriptor(
  name='MysqlSource',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.security_groups', index=1,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.database', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_database', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.service_database', index=3,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.user', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.password', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_tables_regex', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.include_tables_regex', index=6,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_tables_regex', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.exclude_tables_regex', index=7,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.timezone', index=8,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_transfer_settings', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlSource.object_transfer_settings', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=1168,
)


_MYSQLTARGET = _descriptor.Descriptor(
  name='MysqlTarget',
  full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_groups', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.security_groups', index=1,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.database', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.user', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.password', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sql_mode', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.sql_mode', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_constraint_checks', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.skip_constraint_checks', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.timezone', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cleanup_policy', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.cleanup_policy', index=8,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_database', full_name='yandex.cloud.datatransfer.v1.endpoint.MysqlTarget.service_database', index=9,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1554,
)

_ONPREMISEMYSQL.fields_by_name['tls_mode'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._TLSMODE
_MYSQLCONNECTION.fields_by_name['on_premise'].message_type = _ONPREMISEMYSQL
_MYSQLCONNECTION.oneofs_by_name['connection'].fields.append(
  _MYSQLCONNECTION.fields_by_name['mdb_cluster_id'])
_MYSQLCONNECTION.fields_by_name['mdb_cluster_id'].containing_oneof = _MYSQLCONNECTION.oneofs_by_name['connection']
_MYSQLCONNECTION.oneofs_by_name['connection'].fields.append(
  _MYSQLCONNECTION.fields_by_name['on_premise'])
_MYSQLCONNECTION.fields_by_name['on_premise'].containing_oneof = _MYSQLCONNECTION.oneofs_by_name['connection']
_MYSQLOBJECTTRANSFERSETTINGS.fields_by_name['view'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._OBJECTTRANSFERSTAGE
_MYSQLOBJECTTRANSFERSETTINGS.fields_by_name['routine'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._OBJECTTRANSFERSTAGE
_MYSQLOBJECTTRANSFERSETTINGS.fields_by_name['trigger'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._OBJECTTRANSFERSTAGE
_MYSQLOBJECTTRANSFERSETTINGS.fields_by_name['tables'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._OBJECTTRANSFERSTAGE
_MYSQLSOURCE.fields_by_name['connection'].message_type = _MYSQLCONNECTION
_MYSQLSOURCE.fields_by_name['password'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._SECRET
_MYSQLSOURCE.fields_by_name['object_transfer_settings'].message_type = _MYSQLOBJECTTRANSFERSETTINGS
_MYSQLTARGET.fields_by_name['connection'].message_type = _MYSQLCONNECTION
_MYSQLTARGET.fields_by_name['password'].message_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._SECRET
_MYSQLTARGET.fields_by_name['cleanup_policy'].enum_type = yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2._CLEANUPPOLICY
DESCRIPTOR.message_types_by_name['OnPremiseMysql'] = _ONPREMISEMYSQL
DESCRIPTOR.message_types_by_name['MysqlConnection'] = _MYSQLCONNECTION
DESCRIPTOR.message_types_by_name['MysqlObjectTransferSettings'] = _MYSQLOBJECTTRANSFERSETTINGS
DESCRIPTOR.message_types_by_name['MysqlSource'] = _MYSQLSOURCE
DESCRIPTOR.message_types_by_name['MysqlTarget'] = _MYSQLTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OnPremiseMysql = _reflection.GeneratedProtocolMessageType('OnPremiseMysql', (_message.Message,), {
  'DESCRIPTOR' : _ONPREMISEMYSQL,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.OnPremiseMysql)
  })
_sym_db.RegisterMessage(OnPremiseMysql)

MysqlConnection = _reflection.GeneratedProtocolMessageType('MysqlConnection', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLCONNECTION,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MysqlConnection)
  })
_sym_db.RegisterMessage(MysqlConnection)

MysqlObjectTransferSettings = _reflection.GeneratedProtocolMessageType('MysqlObjectTransferSettings', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLOBJECTTRANSFERSETTINGS,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MysqlObjectTransferSettings)
  })
_sym_db.RegisterMessage(MysqlObjectTransferSettings)

MysqlSource = _reflection.GeneratedProtocolMessageType('MysqlSource', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLSOURCE,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MysqlSource)
  })
_sym_db.RegisterMessage(MysqlSource)

MysqlTarget = _reflection.GeneratedProtocolMessageType('MysqlTarget', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLTARGET,
  '__module__' : 'yandex.cloud.datatransfer.v1.endpoint.mysql_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.datatransfer.v1.endpoint.MysqlTarget)
  })
_sym_db.RegisterMessage(MysqlTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/monitoring_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/agent/v1/monitoring_service.proto',
  package='yandex.cloud.loadtesting.agent.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:yandex/cloud/loadtesting/agent/v1/monitoring_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"\xca\x01\n\x10\x41\x64\x64MetricRequest\x12%\n\x13\x63ompute_instance_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x06\x63hunks\x18\x04 \x03(\x0b\x32..yandex.cloud.loadtesting.agent.v1.MetricChunkB\x06\x82\xc8\x31\x02>0\x12#\n\x11\x61gent_instance_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50J\x04\x08\x02\x10\x03\"\x8f\x01\n\x0bMetricChunk\x12?\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32).yandex.cloud.loadtesting.agent.v1.MetricB\x06\x82\xc8\x31\x02>0\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x1b\n\rinstance_host\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x06Metric\x12\x19\n\x0bmetric_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bmetric_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x14\n\x0cmetric_value\x18\x03 \x01(\x01\":\n\x11\x41\x64\x64MetricResponse\x12\x17\n\x0fmetric_trail_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x32\xc8\x01\n\x11MonitoringService\x12\xb2\x01\n\tAddMetric\x12\x33.yandex.cloud.loadtesting.agent.v1.AddMetricRequest\x1a\x34.yandex.cloud.loadtesting.agent.v1.AddMetricResponse\":\x82\xd3\xe4\x93\x02\x34\"//loadtesting/agent/v1/monitorings/reportMetrics:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_ADDMETRICREQUEST = _descriptor.Descriptor(
  name='AddMetricRequest',
  full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.compute_instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.job_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunks', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.chunks', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_instance_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricRequest.agent_instance_id', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=361,
)


_METRICCHUNK = _descriptor.Descriptor(
  name='MetricChunk',
  full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.comment', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_host', full_name='yandex.cloud.loadtesting.agent.v1.MetricChunk.instance_host', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=507,
)


_METRIC = _descriptor.Descriptor(
  name='Metric',
  full_name='yandex.cloud.loadtesting.agent.v1.Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_type', full_name='yandex.cloud.loadtesting.agent.v1.Metric.metric_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='yandex.cloud.loadtesting.agent.v1.Metric.metric_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_value', full_name='yandex.cloud.loadtesting.agent.v1.Metric.metric_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=593,
)


_ADDMETRICRESPONSE = _descriptor.Descriptor(
  name='AddMetricResponse',
  full_name='yandex.cloud.loadtesting.agent.v1.AddMetricResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_trail_id', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricResponse.metric_trail_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='yandex.cloud.loadtesting.agent.v1.AddMetricResponse.code', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=653,
)

_ADDMETRICREQUEST.fields_by_name['chunks'].message_type = _METRICCHUNK
_METRICCHUNK.fields_by_name['data'].message_type = _METRIC
DESCRIPTOR.message_types_by_name['AddMetricRequest'] = _ADDMETRICREQUEST
DESCRIPTOR.message_types_by_name['MetricChunk'] = _METRICCHUNK
DESCRIPTOR.message_types_by_name['Metric'] = _METRIC
DESCRIPTOR.message_types_by_name['AddMetricResponse'] = _ADDMETRICRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AddMetricRequest = _reflection.GeneratedProtocolMessageType('AddMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDMETRICREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.AddMetricRequest)
  })
_sym_db.RegisterMessage(AddMetricRequest)

MetricChunk = _reflection.GeneratedProtocolMessageType('MetricChunk', (_message.Message,), {
  'DESCRIPTOR' : _METRICCHUNK,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.MetricChunk)
  })
_sym_db.RegisterMessage(MetricChunk)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.Metric)
  })
_sym_db.RegisterMessage(Metric)

AddMetricResponse = _reflection.GeneratedProtocolMessageType('AddMetricResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDMETRICRESPONSE,
  '__module__' : 'yandex.cloud.loadtesting.agent.v1.monitoring_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.agent.v1.AddMetricResponse)
  })
_sym_db.RegisterMessage(AddMetricResponse)


DESCRIPTOR._options = None
_ADDMETRICREQUEST.fields_by_name['compute_instance_id']._options = None
_ADDMETRICREQUEST.fields_by_name['job_id']._options = None
_ADDMETRICREQUEST.fields_by_name['chunks']._options = None
_ADDMETRICREQUEST.fields_by_name['agent_instance_id']._options = None
_METRICCHUNK.fields_by_name['data']._options = None
_METRICCHUNK.fields_by_name['instance_host']._options = None
_METRIC.fields_by_name['metric_type']._options = None
_METRIC.fields_by_name['metric_name']._options = None

_MONITORINGSERVICE = _descriptor.ServiceDescriptor(
  name='MonitoringService',
  full_name='yandex.cloud.loadtesting.agent.v1.MonitoringService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=656,
  serialized_end=856,
  methods=[
  _descriptor.MethodDescriptor(
    name='AddMetric',
    full_name='yandex.cloud.loadtesting.agent.v1.MonitoringService.AddMetric',
    index=0,
    containing_service=None,
    input_type=_ADDMETRICREQUEST,
    output_type=_ADDMETRICRESPONSE,
    serialized_options=b'\202\323\344\223\0024\"//loadtesting/agent/v1/monitorings/reportMetrics:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MONITORINGSERVICE)

DESCRIPTOR.services_by_name['MonitoringService'] = _MONITORINGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/group_mapping.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/organizationmanager/v1/group_mapping.proto',
  package='yandex.cloud.organizationmanager.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/organizationmanager/v1/group_mapping.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1dyandex/cloud/validation.proto\"f\n\x10GroupMappingItem\x12)\n\x11\x65xternal_group_id\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1000\x12\'\n\x11internal_group_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x0cGroupMapping\x12\x15\n\rfederation_id\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x42\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GROUPMAPPINGITEM = _descriptor.Descriptor(
  name='GroupMappingItem',
  full_name='yandex.cloud.organizationmanager.v1.GroupMappingItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_group_id', full_name='yandex.cloud.organizationmanager.v1.GroupMappingItem.external_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_group_id', full_name='yandex.cloud.organizationmanager.v1.GroupMappingItem.internal_group_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=229,
)


_GROUPMAPPING = _descriptor.Descriptor(
  name='GroupMapping',
  full_name='yandex.cloud.organizationmanager.v1.GroupMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='federation_id', full_name='yandex.cloud.organizationmanager.v1.GroupMapping.federation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.organizationmanager.v1.GroupMapping.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=285,
)

DESCRIPTOR.message_types_by_name['GroupMappingItem'] = _GROUPMAPPINGITEM
DESCRIPTOR.message_types_by_name['GroupMapping'] = _GROUPMAPPING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GroupMappingItem = _reflection.GeneratedProtocolMessageType('GroupMappingItem', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMAPPINGITEM,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GroupMappingItem)
  })
_sym_db.RegisterMessage(GroupMappingItem)

GroupMapping = _reflection.GeneratedProtocolMessageType('GroupMapping', (_message.Message,), {
  'DESCRIPTOR' : _GROUPMAPPING,
  '__module__' : 'yandex.cloud.organizationmanager.v1.group_mapping_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.organizationmanager.v1.GroupMapping)
  })
_sym_db.RegisterMessage(GroupMapping)


DESCRIPTOR._options = None
_GROUPMAPPINGITEM.fields_by_name['external_group_id']._options = None
_GROUPMAPPINGITEM.fields_by_name['internal_group_id']._options = None
# @@protoc_insertion_point(module_scope)
